@@ -598,9 +598,11 @@ void sftpProtocol::openConnection() {
     return;
   }
 
-  kDebug(KIO_SFTP_DB) << "username=" << mUsername << ", host=" << mHost << ", port=" << mPort;
+  const int effectivePort = mPort > 0 ? mPort : DEFAULT_SFTP_PORT;
 
-  infoMessage(i18n("Opening SFTP connection to host %1:%2", mHost, mPort));
+  kDebug(KIO_SFTP_DB) << "username=" << mUsername << ", host=" << mHost << ", port=" << effectivePort;
+
+  infoMessage(i18n("Opening SFTP connection to host %1:<numid>%2</numid>", mHost, effectivePort));
 
   if (mHost.isEmpty()) {
     kDebug(KIO_SFTP_DB) << "openConnection(): Need hostname...";
@@ -1472,7 +1474,11 @@ sftpProtocol::StatusCode sftpProtocol::sftpPut(const KUrl& url, int permissions,
         times[1].tv_sec =  dt.toTime_t(); // modification time
         times[0].tv_usec = times[1].tv_usec = 0;
 
-        sftp_utimes(mSftp, dest_orig_c.constData(), times);
+        kDebug(KIO_SFTP_DB) << "Trying to restore mtime for " << dest_orig << " to: " << mtimeStr;
+        result = sftp_utimes(mSftp, dest_orig_c.constData(), times);
+        if (result < 0) {
+            kWarning(KIO_SFTP_DB) << "Failed to set mtime for" << dest_orig;
+        }
         sftp_attributes_free(attr);
       }
     }
@@ -1616,17 +1622,6 @@ sftpProtocol::StatusCode sftpProtocol::sftpCopyGet(const KUrl& url, const QStrin
     }
   }
 
-  const QString mtimeStr = metaData("modified");
-  if (!mtimeStr.isEmpty()) {
-    QDateTime dt = QDateTime::fromString(mtimeStr, Qt::ISODate);
-    if (dt.isValid()) {
-      struct utimbuf utbuf;
-      utbuf.actime = buff.st_atime; // access time, unchanged
-      utbuf.modtime = dt.toTime_t(); // modification time
-      KDE::utime(sCopyFile, &utbuf);
-    }
-  }
-
   return result;
 }
 
