@@ -279,7 +279,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     // Environment variable expansion.
     if ( sEnvVarExp.indexIn( path ) == 0 )
     {
-      const char* exp = getenv( path.mid( 1, sEnvVarExp.matchedLength() - 1 ).toLocal8Bit().data() );
+      const char* exp = qgetenv( path.mid( 1, sEnvVarExp.matchedLength() - 1 ).toLocal8Bit().data() );
       if(exp)
       {
         path.replace( 0, sEnvVarExp.matchedLength(), QString::fromLocal8Bit(exp) );
