@@ -1,5 +1,6 @@
 /* This file is part of the KDE Project
    Copyright (c) 2007-2010 Sebastian Trueg <trueg@kde.org>
+   Copyright (c) 2012-2013 Vishesh Handa <me@vhanda.in>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,7 +25,7 @@
 #include "fileindexerinterface.h"
 #include "indexfolderselectiondialog.h"
 #include "excludefilterselectiondialog.h"
-#include "statuswidget.h"
+#include "detailswidget.h"
 #include "removablemediacache.h"
 
 #include <KPluginFactory>
@@ -95,6 +96,7 @@ Nepomuk2::ServerConfigModule::ServerConfigModule( QWidget* parent, const QVarian
     : KCModule( NepomukConfigModuleFactory::componentData(), parent, args ),
       m_serverInterface( 0 ),
       m_fileIndexerInterface( 0 ),
+      m_akonadiInterface( 0 ),
       m_failedToInitialize( false ),
       m_checkboxesChanged( false )
 {
@@ -118,6 +120,7 @@ Nepomuk2::ServerConfigModule::ServerConfigModule( QWidget* parent, const QVarian
         QDBusServiceWatcher * watcher = new QDBusServiceWatcher( this );
         watcher->addWatchedService( QLatin1String("org.kde.nepomuk.services.nepomukfileindexer") );
         watcher->addWatchedService( QLatin1String("org.kde.NepomukServer") );
+        watcher->addWatchedService( QLatin1String("org.freedesktop.Akonadi.Agent.akonadi_nepomuk_feeder") );
         watcher->setConnection( QDBusConnection::sessionBus() );
         watcher->setWatchMode( QDBusServiceWatcher::WatchForRegistration | QDBusServiceWatcher::WatchForUnregistration );
 
@@ -143,8 +146,14 @@ Nepomuk2::ServerConfigModule::ServerConfigModule( QWidget* parent, const QVarian
                  this, SLOT( slotEditIndexFolders() ) );
         connect( m_buttonAdvancedFileIndexing, SIGNAL( clicked() ),
                  this, SLOT( slotAdvancedFileIndexing() ) );
+        connect( m_fileIndexerSuspendResumeButtom, SIGNAL(clicked(bool)),
+                 this, SLOT(slotFileIndexerSuspendResumeClicked()) );
+        connect( m_emailIndexerSuspendResumeButtom, SIGNAL(clicked(bool)),
+                 this, SLOT(slotEmailIndexerSuspendResumeClicked()) );
         connect( m_buttonDetails, SIGNAL( leftClickedUrl() ),
                  this, SLOT( slotStatusDetailsClicked() ) );
+        connect( m_buttonCheckForNewFiles, SIGNAL( clicked() ),
+                 this, SLOT( slotUpdateAllFolders() ) );
 
         connect( m_checkboxAudio, SIGNAL(toggled(bool)),
                  this, SLOT(slotCheckBoxesChanged()) );
@@ -202,6 +211,7 @@ Nepomuk2::ServerConfigModule::ServerConfigModule( QWidget* parent, const QVarian
 Nepomuk2::ServerConfigModule::~ServerConfigModule()
 {
     delete m_fileIndexerInterface;
+    delete m_akonadiInterface;
     delete m_serverInterface;
 }
 
@@ -295,6 +305,7 @@ void Nepomuk2::ServerConfigModule::load()
 
     recreateInterfaces();
     updateFileIndexerStatus();
+    updateEmailIndexerStatus();
     updateNepomukServerStatus();
 
     // 7. all values loaded -> no changes
@@ -421,6 +432,7 @@ void Nepomuk2::ServerConfigModule::save()
     // 5. update state
     recreateInterfaces();
     updateFileIndexerStatus();
+    updateEmailIndexerStatus();
     updateNepomukServerStatus();
 
 
@@ -480,6 +492,7 @@ void Nepomuk2::ServerConfigModule::updateFileIndexerStatus()
             else {
                 m_failedToInitialize = false;
                 setFileIndexerStatusText( status, true );
+                updateFileIndexerSuspendResumeButtonText( m_fileIndexerInterface->isSuspended() );
             }
         }
         else {
@@ -493,6 +506,90 @@ void Nepomuk2::ServerConfigModule::updateFileIndexerStatus()
     }
 }
 
+void Nepomuk2::ServerConfigModule::updateFileIndexerSuspendResumeButtonText(bool isSuspended)
+{
+    if( isSuspended ) {
+        m_fileIndexerSuspendResumeButtom->setText( i18nc("Resumes the Nepomuk file indexing service.","Resume") );
+        m_fileIndexerSuspendResumeButtom->setIcon( KIcon("media-playback-start") );
+    }
+    else {
+        m_fileIndexerSuspendResumeButtom->setText( i18nc("Suspends the Nepomuk file indexing service.","Suspend") );
+        m_fileIndexerSuspendResumeButtom->setIcon( KIcon("media-playback-pause") );
+    }
+}
+
+void Nepomuk2::ServerConfigModule::slotFileIndexerSuspendResumeClicked()
+{
+    bool suspended = m_fileIndexerInterface->isSuspended();
+    if( !suspended ) {
+        m_fileIndexerInterface->suspend();
+        updateFileIndexerSuspendResumeButtonText( true );
+    }
+    else {
+        m_fileIndexerInterface->resume();
+        updateFileIndexerSuspendResumeButtonText( false );
+    }
+}
+
+void Nepomuk2::ServerConfigModule::setEmailIndexerStatusText( const QString& text, bool elide )
+{
+    m_labelEmailIndexerStatus->setWordWrap( !elide );
+    m_labelEmailIndexerStatus->setTextElideMode( elide ? Qt::ElideMiddle : Qt::ElideNone );
+    m_labelEmailIndexerStatus->setText( text );
+}
+
+void Nepomuk2::ServerConfigModule::updateEmailIndexerStatus()
+{
+    if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( "org.freedesktop.Akonadi.Agent.akonadi_nepomuk_feeder" ) ) {
+        bool isOnline = m_akonadiInterface->isOnline();
+        if( isOnline ) {
+            QString statusMessage = m_akonadiInterface->statusMessage();
+            int percent = m_akonadiInterface->progress();
+            QString status = i18nc( "<status string> (<percentage>%)", "%1 (%2%)", statusMessage, percent );
+
+            if ( status.isEmpty() ) {
+                setEmailIndexerStatusText( i18nc( "@info:status %1 is an error message returned by a dbus interface.",
+                                                 "Failed to contact Email Indexer service (%1)",
+                                                 m_akonadiInterface->lastError().message() ), false );
+            }
+            else {
+                setEmailIndexerStatusText( status, true );
+                updateEmailIndexerSuspendResumeButtonText( !isOnline );
+            }
+        }
+        else {
+            setEmailIndexerStatusText( i18nc( "@info:status", "Email Indexing service is suspended" ), false );
+        }
+    }
+    else {
+        setEmailIndexerStatusText( i18nc( "@info:status", "Email indexing service not running." ), false );
+    }
+}
+
+void Nepomuk2::ServerConfigModule::updateEmailIndexerSuspendResumeButtonText(bool isSuspended)
+{
+    if( isSuspended ) {
+        m_emailIndexerSuspendResumeButtom->setText( i18n("Resume") );
+        m_emailIndexerSuspendResumeButtom->setIcon( KIcon("media-playback-start") );
+    }
+    else {
+        m_emailIndexerSuspendResumeButtom->setText( i18n("Suspend") );
+        m_emailIndexerSuspendResumeButtom->setIcon( KIcon("media-playback-pause") );
+    }
+}
+
+void Nepomuk2::ServerConfigModule::slotEmailIndexerSuspendResumeClicked()
+{
+    bool suspended = !m_akonadiInterface->isOnline();
+    if( !suspended ) {
+        m_akonadiInterface->setOnline(false);
+        updateEmailIndexerSuspendResumeButtonText( true );
+    }
+    else {
+        m_akonadiInterface->setOnline(true);
+        updateEmailIndexerSuspendResumeButtonText( false );
+    }
+}
 
 void Nepomuk2::ServerConfigModule::updateBackupStatus()
 {
@@ -505,7 +602,7 @@ void Nepomuk2::ServerConfigModule::updateBackupStatus()
         text += QLatin1String(" (");
         text += i18nc("@info %1 is the creation date of a backup formatted vi KLocale::formatDateTime",
                       "Oldest: %1",
-                      KGlobal::locale()->formatDateTime(QFileInfo(backupUrl+QLatin1String("/")+backupFiles.last()).created(), KLocale::FancyShortDate));
+                      KGlobal::locale()->formatDateTime(QFileInfo(backupUrl+QLatin1String("/")+backupFiles.first()).created(), KLocale::FancyShortDate));
         text += QLatin1String(")");
     }
 
@@ -516,20 +613,26 @@ void Nepomuk2::ServerConfigModule::updateBackupStatus()
 void Nepomuk2::ServerConfigModule::recreateInterfaces()
 {
     delete m_fileIndexerInterface;
+    delete m_akonadiInterface;
     delete m_serverInterface;
 
     m_fileIndexerInterface = new org::kde::nepomuk::FileIndexer( "org.kde.nepomuk.services.nepomukfileindexer", "/nepomukfileindexer", QDBusConnection::sessionBus() );
     m_serverInterface = new org::kde::NepomukServer( "org.kde.NepomukServer", "/nepomukserver", QDBusConnection::sessionBus() );
+    m_akonadiInterface = new org::freedesktop::Akonadi::Agent::Status( "org.freedesktop.Akonadi.Agent.akonadi_nepomuk_feeder", "/", QDBusConnection::sessionBus() );
 
     connect( m_fileIndexerInterface, SIGNAL( statusChanged() ),
              this, SLOT( updateFileIndexerStatus() ) );
+    connect( m_akonadiInterface, SIGNAL(percent(int)),
+             this, SLOT(updateEmailIndexerStatus()) );
+    connect( m_akonadiInterface, SIGNAL(status(int,QString)),
+             this, SLOT(updateEmailIndexerStatus()) );
 }
 
 
 void Nepomuk2::ServerConfigModule::slotStatusDetailsClicked()
 {
-    StatusWidget statusDialog( this );
-    statusDialog.exec();
+    DetailsWidget dialog( this );
+    dialog.exec();
 }
 
 
@@ -670,5 +773,9 @@ void Nepomuk2::ServerConfigModule::slotCheckBoxesChanged()
     changed( true );
 }
 
+void Nepomuk2::ServerConfigModule::slotUpdateAllFolders()
+{
+     m_fileIndexerInterface->updateAllFolders( true );
+}
 
 #include "nepomukserverkcm.moc"
