@@ -23,6 +23,7 @@
 #include "ui_nepomukconfigwidget.h"
 #include "nepomukserverinterface.h"
 #include "fileindexerinterface.h"
+#include "akonadifeederinterface.h"
 
 #include <Nepomuk2/Query/Query>
 
@@ -32,6 +33,7 @@ class QAbstractButton;
 namespace Nepomuk2 {
 
     class IndexFolderSelectionDialog;
+    class ExcludeFilterSelectionDialog;
     class StatusWidget;
 
     class ServerConfigModule : public KCModule, private Ui::NepomukConfigWidget
@@ -50,32 +52,47 @@ namespace Nepomuk2 {
     private Q_SLOTS:
         void updateNepomukServerStatus();
         void updateFileIndexerStatus();
+        void updateEmailIndexerStatus();
         void updateBackupStatus();
         void recreateInterfaces();
-        void slotCustomQueryButtonClicked();
         void slotEditIndexFolders();
-        void slotCustomQueryToggled( bool );
+        void slotAdvancedFileIndexing();
         void slotStatusDetailsClicked();
+        void slotFileIndexerSuspendResumeClicked();
+        void slotEmailIndexerSuspendResumeClicked();
         void slotBackupFrequencyChanged();
         void slotManualBackup();
         void slotRestoreBackup();
+        void slotUpdateAllFolders();
+
+        /**
+         * This slot is called when any of the "index documents", "index whatever" checkboxes
+         * status is chanaged
+         */
+        void slotCheckBoxesChanged();
 
     private:
         void setFileIndexerStatusText( const QString& text, bool elide );
+        void setEmailIndexerStatusText( const QString& text, bool elide );
 
-        QRadioButton* buttonForQuery( const Query::Query& query ) const;
-        Nepomuk2::Query::Query queryForButton( QAbstractButton* button ) const;
+        void updateFileIndexerSuspendResumeButtonText(bool isSuspended);
+        void updateEmailIndexerSuspendResumeButtonText(bool isSuspended);
+
+        void syncCheckBoxesFromMimetypes(const QStringList& mimetypes);
+        QStringList mimetypesFromCheckboxes();
 
         bool m_nepomukAvailable;
 
         org::kde::NepomukServer* m_serverInterface;
         org::kde::nepomuk::FileIndexer* m_fileIndexerInterface;
+        org::freedesktop::Akonadi::Agent::Status* m_akonadiInterface;
 
         IndexFolderSelectionDialog* m_indexFolderSelectionDialog;
+        ExcludeFilterSelectionDialog* m_excludeFilterSelectionDialog;
 
         bool m_failedToInitialize;
 
-        QString m_customQuery;
+        bool m_checkboxesChanged;
     };
 }
 
