@@ -57,15 +57,16 @@ K_PLUGIN_FACTORY(PhononServerFactory,
         )
 K_EXPORT_PLUGIN(PhononServerFactory("phononserver"))
 
+using namespace Phonon;
+
+
 PhononServer::PhononServer(QObject *parent, const QList<QVariant> &)
     : KDEDModule(parent),
     m_config(KSharedConfig::openConfig("phonondevicesrc", KConfig::SimpleConfig))
 {
     findDevices();
-    connect(Solid::DeviceNotifier::instance(), SIGNAL(deviceAdded(const QString &)), SLOT(deviceAdded(const QString &)));
-    connect(Solid::DeviceNotifier::instance(), SIGNAL(deviceRemoved(const QString &)), SLOT(deviceRemoved(const QString &)));
-
-    Phonon::registerMetaTypes();
+    connect(Solid::DeviceNotifier::instance(), SIGNAL(deviceAdded(QString)), SLOT(deviceAdded(QString)));
+    connect(Solid::DeviceNotifier::instance(), SIGNAL(deviceRemoved(QString)), SLOT(deviceRemoved(QString)));
 }
 
 PhononServer::~PhononServer()
@@ -225,7 +226,7 @@ void PhononServer::findVirtualDevices()
 
                 cardName = alsaDeviceName.mid(cardNameStart, cardNameEnd - cardNameStart);
             } else {
-                cardName = i18n("Unknown");
+                cardName = i18nc("unknown sound card", "Unknown");
             }
         }
 
@@ -606,16 +607,15 @@ void PhononServer::findDevices()
         }
 
         kDebug(601) << "Solid video device:" << hwDevice.product() << hwDevice.description();
-        foreach (const QString driverName, videoDevice->supportedDrivers()) {
+        foreach (const QString & driverName, videoDevice->supportedDrivers()) {
             kDebug(601) << "- driver" << driverName << ":" << videoDevice->driverHandle(driverName);
         }
 
-        // Iterate through the supported drivers to create different acccess objects for each one
-        foreach (const QString driverName, videoDevice->supportedDrivers()) {
+        // Iterate through the supported drivers to create different access objects for each one
+        foreach (const QString & driverName, videoDevice->supportedDrivers()) {
             deviceIds.clear();
             accessPreference = 0;
             driver = PS::DeviceAccess::InvalidDriver;
-            valid = true;
             isAdvanced = false;
 
             QVariant handle = videoDevice->driverHandle(driverName);
@@ -640,10 +640,6 @@ void PhononServer::findDevices()
              * else to do here
              */
 
-            if (!valid) {
-                continue;
-            }
-
             m_udisOfDevices.append(hwDevice.udi());
 
             PS::DeviceAccess devAccess(deviceIds, accessPreference, driver, true, false);
@@ -766,7 +762,7 @@ void PhononServer::findDevices()
         qSort(askToRemoveAudio);
         QMetaObject::invokeMethod(this, "askToRemoveDevices", Qt::QueuedConnection,
                 Q_ARG(QStringList, askToRemoveAudio),
-                Q_ARG(int, Phonon::AudioOutputDeviceType | Phonon::AudioCaptureDeviceType),
+                Q_ARG(int, AudioOutputDeviceType | AudioCaptureDeviceType),
                 Q_ARG(QList<int>, askToRemoveAudioIndexes));
     }
 
@@ -774,7 +770,7 @@ void PhononServer::findDevices()
         qSort(askToRemoveVideo);
         QMetaObject::invokeMethod(this, "askToRemoveDevices", Qt::QueuedConnection,
                 Q_ARG(QStringList, askToRemoveVideo),
-                Q_ARG(int, Phonon::VideoCaptureDeviceType),
+                Q_ARG(int, VideoCaptureDeviceType),
                 Q_ARG(QList<int>, askToRemoveVideoIndexes));
     }
 
@@ -813,10 +809,10 @@ QByteArray PhononServer::audioDevicesIndexes(int type)
     QByteArray *v;
 
     switch (type) {
-    case Phonon::AudioOutputDeviceType:
+    case AudioOutputDeviceType:
         v = &m_audioOutputDevicesIndexesCache;
         break;
-    case Phonon::AudioCaptureDeviceType:
+    case AudioCaptureDeviceType:
         v = &m_audioCaptureDevicesIndexesCache;
         break;
     default:
@@ -832,7 +828,7 @@ QByteArray PhononServer::audioDevicesIndexes(int type)
 
 QByteArray PhononServer::videoDevicesIndexes(int type)
 {
-    if (type != Phonon::VideoCaptureDeviceType)
+    if (type != VideoCaptureDeviceType)
         return QByteArray();
 
     if (m_videoCaptureDevicesIndexesCache.isEmpty()) {
@@ -974,11 +970,11 @@ inline static void insertGenericProperties(const PS::DeviceInfo &dev, QHash<QByt
 
 inline static void insertDALProperty(const PS::DeviceInfo &dev, QHash<QByteArray, QVariant> &p)
 {
-    Phonon::DeviceAccessList deviceAccessList;
+    DeviceAccessList deviceAccessList;
     foreach (const PS::DeviceAccess &access, dev.accessList()) {
         const QByteArray &driver = nameForDriver(access.driver());
         foreach (const QString &deviceId, access.deviceIds()) {
-            deviceAccessList << Phonon::DeviceAccess(driver, deviceId);
+            deviceAccessList << DeviceAccess(driver, deviceId);
         }
     }
 
@@ -992,7 +988,7 @@ void PhononServer::updateDevicesCache()
         QHash<QByteArray, QVariant> properties;
         insertGenericProperties(dev, properties);
 
-        Phonon::DeviceAccessList deviceAccessList;
+        DeviceAccessList deviceAccessList;
         bool first = true;
         QStringList oldDeviceIds;
         PS::DeviceAccess::DeviceDriverType driverId = PS::DeviceAccess::InvalidDriver;
@@ -1008,7 +1004,7 @@ void PhononServer::updateDevicesCache()
                 if (access.driver() == driverId) {
                     oldDeviceIds << deviceId;
                 }
-                deviceAccessList << Phonon::DeviceAccess(driver, deviceId);
+                deviceAccessList << DeviceAccess(driver, deviceId);
             }
         }
 
@@ -1079,8 +1075,8 @@ void PhononServer::deviceRemoved(const QString &udi)
 
 void PhononServer::askToRemoveDevices(const QStringList &devList, int type, const QList< int >& indexes)
 {
-    bool areAudio = type & (Phonon::AudioOutputDeviceType | Phonon::AudioCaptureDeviceType);
-    bool areVideo = type & Phonon::VideoCaptureDeviceType;
+    bool areAudio = type & (AudioOutputDeviceType | AudioCaptureDeviceType);
+    bool areVideo = type & VideoCaptureDeviceType;
 
     if (!areAudio && !areVideo)
         return;
